
<div class="h3-box" markdown="1">

### {{include.title}}

{{include.description}}

**Input File Format:**

```
{{include.file_format}}
```

**Constructor Parameters:**

{{include.constructor}}

**Parameters for `readDataset`:**

{{include.read_dataset_params}}

Refer to the documentation for more details on the API:

| **Python API:** {{include.python_api_link}} | **Scala API:** {{include.api_link}} |

<details>

<summary class="button"><b>Show Example</b></summary>

<div class="tabs-new" markdown="1">

{% include programmingLanguageSelectScalaPython.html %}

```python
{{include.python_example}}
```

```scala
{{include.scala_example}}
```

</div>

</details>

</div>
